@@ -1,3 +1,4 @@
+import dask.dataframe as dd
 from woodwork.column_schema import ColumnSchema
 from woodwork.logical_types import Boolean, BooleanNullable
 
@@ -10,8 +11,11 @@ from featuretools.primitives.base import (
     PrimitiveBase,
     TransformPrimitive,
 )
+from featuretools.utils.gen_utils import Library, import_or_none, is_instance
 from featuretools.utils.wrangle import _check_time_against_column, _check_timedelta
 
+ps = import_or_none("pyspark.pandas")
+
 _ES_REF = {}
 
 
@@ -47,6 +51,13 @@ class FeatureBase(object):
         # initialize if not already initialized
         if not isinstance(primitive, PrimitiveBase):
             primitive = primitive()
+
+        # default library is PANDAS
+        if isinstance(dataframe, dd.DataFrame):
+            primitive.series_library = Library.DASK
+        elif is_instance(dataframe, ps, "DataFrame"):
+            primitive.series_library = Library.SPARK
+
         self.primitive = primitive
 
         self.relationship_path = relationship_path
