@@ -301,13 +301,13 @@ class DiffDatetime(Diff):
     Examples:
         >>> from datetime import datetime
         >>> dt_values = [datetime(2019, 3, 1), datetime(2019, 6, 30), datetime(2019, 11, 17), datetime(2020, 1, 30), datetime(2020, 3, 11)]
-        >>> diff_dt = Diff()
+        >>> diff_dt = DiffDatetime()
         >>> diff_dt(dt_values).tolist()
         [NaT, Timedelta('121 days 00:00:00'), Timedelta('140 days 00:00:00'), Timedelta('74 days 00:00:00'), Timedelta('41 days 00:00:00')]
 
         You can specify the number of periods to shift the values
 
-        >>> diff_dt_periods = Diff(periods = 1)
+        >>> diff_dt_periods = DiffDatetime(periods = 1)
         >>> diff_dt_periods(dt_values).tolist()
         [NaT, NaT, Timedelta('121 days 00:00:00'), Timedelta('140 days 00:00:00'), Timedelta('74 days 00:00:00')]
     """
@@ -653,10 +653,14 @@ class Lag(TransformPrimitive):
         You can specify the number of periods to shift the values
 
         >>> lag_periods = Lag(periods=3)
-        >>> lag_periods(["hello", "world", "test", "foo", "bar"], pd.Series(pd.date_range(start="2020-01-01", periods=5, freq='D'))).tolist()
-        [nan, nan, nan, 'hello', 'world']
+        >>> lag_periods([True, False, False, True, True], pd.Series(pd.date_range(start="2020-01-01", periods=5, freq='D'))).tolist()
+        [nan, nan, nan, True, False]
     """
 
+    # Note: with pandas 1.5.0, using Lag with a string input will result in `None` values
+    # being introduced instead of `nan` values that were present in previous versions.
+    # All missing values will be replaced by `np.nan` (for Double) or `pd.NA` (all other types)
+    # once Woodwork is initialized on the feature matrix.
     name = "lag"
     input_types = [
         [
