@@ -20,7 +20,7 @@ from featuretools.utils.gen_utils import Library
 BUCKET_NAME = "test-bucket"
 WRITE_KEY_NAME = "test-key"
 TEST_S3_URL = "s3://{}/{}".format(BUCKET_NAME, WRITE_KEY_NAME)
-TEST_FILE = "test_serialization_data_entityset_schema_{}_2022_4_26.tar".format(
+TEST_FILE = "test_serialization_data_entityset_schema_{}_2022_09_02.tar".format(
     SCHEMA_VERSION,
 )
 S3_URL = "s3://featuretools-static/" + TEST_FILE
@@ -241,7 +241,7 @@ def make_public(s3_client, s3_bucket):
 # TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Spark
 @pytest.mark.parametrize("profile_name", [None, False])
 def test_serialize_s3_csv(es, s3_client, s3_bucket, profile_name):
-    if es.dataframe_type != Library.PANDAS.value:
+    if es.dataframe_type != Library.PANDAS:
         pytest.xfail(
             "tmp file disappears after deserialize step, cannot check equality with Dask",
         )
@@ -263,7 +263,7 @@ def test_serialize_s3_pickle(pd_es, s3_client, s3_bucket, profile_name):
 # TODO: tmp file disappears after deserialize step, cannot check equality with Dask, Spark
 @pytest.mark.parametrize("profile_name", [None, False])
 def test_serialize_s3_parquet(es, s3_client, s3_bucket, profile_name):
-    if es.dataframe_type != Library.PANDAS.value:
+    if es.dataframe_type != Library.PANDAS:
         pytest.xfail(
             "tmp file disappears after deserialize step, cannot check equality with Dask or Spark",
         )
@@ -312,7 +312,7 @@ def setup_test_profile(monkeypatch, tmpdir):
 
 
 def test_s3_test_profile(es, s3_client, s3_bucket, setup_test_profile):
-    if es.dataframe_type != Library.PANDAS.value:
+    if es.dataframe_type != Library.PANDAS:
         pytest.xfail(
             "tmp file disappears after deserialize step, cannot check equality with Dask",
         )
@@ -333,7 +333,7 @@ def test_serialize_subdirs_not_removed(es, tmpdir):
     test_dir = write_path.mkdir("test_dir")
     with open(str(write_path.join("data_description.json")), "w") as f:
         json.dump("__SAMPLE_TEXT__", f)
-    if es.dataframe_type == Library.SPARK.value:
+    if es.dataframe_type == Library.SPARK:
         compression = "none"
     else:
         compression = None
@@ -416,7 +416,7 @@ def test_operations_invalidate_metadata(es):
     assert new_es._data_description is not None
 
     # automatically adding interesting values not supported in Dask or Spark
-    if new_es.dataframe_type == Library.PANDAS.value:
+    if new_es.dataframe_type == Library.PANDAS:
         new_es.add_interesting_values()
         assert new_es._data_description is None
         assert new_es.metadata is not None
@@ -484,6 +484,7 @@ def _check_schema_version(version, es, warning_text, caplog, warning_type=None):
         "id": es.id,
         "dataframes": dataframes,
         "relationships": relationships,
+        "data_type": es.dataframe_type,
     }
 
     if warning_type == "log" and warning_text:
