@@ -1,7 +1,17 @@
+from unittest.mock import patch
+
 import numpy as np
 import pandas as pd
 import pytest
 
+from featuretools.primitives import (
+    RollingCount,
+    RollingMax,
+    RollingMean,
+    RollingMin,
+    RollingSTD,
+    RollingTrend,
+)
 from featuretools.primitives.rolling_primitive_utils import (
     _get_rolled_series_without_gap,
     apply_roll_with_offset_gap,
@@ -40,8 +50,9 @@ def test_get_rolled_series_without_gap_large_bound(rolling_series_pd):
     assert (
         len(
             _get_rolled_series_without_gap(
-                rolling_series_pd.iloc[[0, 2, 5, 6, 8, 9]], "20D"
-            )
+                rolling_series_pd.iloc[[0, 2, 5, 6, 8, 9]],
+                "20D",
+            ),
         )
         == 0
     )
@@ -59,8 +70,18 @@ def test_get_rolled_series_without_gap_large_bound(rolling_series_pd):
     ],
 )
 def test_roll_series_with_gap(window_length, gap, rolling_series_pd):
-    rolling_max = roll_series_with_gap(rolling_series_pd, window_length, gap=gap).max()
-    rolling_min = roll_series_with_gap(rolling_series_pd, window_length, gap=gap).min()
+    rolling_max = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=1,
+    ).max()
+    rolling_min = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=1,
+    ).min()
 
     assert len(rolling_max) == len(rolling_series_pd)
     assert len(rolling_min) == len(rolling_series_pd)
@@ -94,7 +115,12 @@ def test_roll_series_with_gap(window_length, gap, rolling_series_pd):
 
 @pytest.mark.parametrize("window_length", [3, "3d"])
 def test_roll_series_with_no_gap(window_length, rolling_series_pd):
-    actual_rolling = roll_series_with_gap(rolling_series_pd, window_length).mean()
+    actual_rolling = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=0,
+        min_periods=1,
+    ).mean()
     expected_rolling = rolling_series_pd.rolling(window_length, min_periods=1).mean()
 
     pd.testing.assert_series_equal(actual_rolling, expected_rolling)
@@ -115,13 +141,16 @@ def test_roll_series_with_gap_early_values(window_length, gap, rolling_series_pd
 
     # Default min periods is 1 - will include all
     default_partial_values = roll_series_with_gap(
-        rolling_series_pd, window_length, gap=gap
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=1,
     ).count()
     num_empty_aggregates = len(default_partial_values.loc[default_partial_values == 0])
     num_partial_aggregates = len(
         (default_partial_values.loc[default_partial_values != 0]).loc[
             default_partial_values < window_length_num
-        ]
+        ],
     )
 
     assert num_partial_aggregates == window_length_num - 1
@@ -133,11 +162,14 @@ def test_roll_series_with_gap_early_values(window_length, gap, rolling_series_pd
 
     # Make min periods the size of the window
     no_partial_values = roll_series_with_gap(
-        rolling_series_pd, window_length, gap=gap, min_periods=window_length_num
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=window_length_num,
     ).count()
     num_null_aggregates = len(no_partial_values.loc[pd.isna(no_partial_values)])
     num_partial_aggregates = len(
-        no_partial_values.loc[no_partial_values < window_length_num]
+        no_partial_values.loc[no_partial_values < window_length_num],
     )
 
     # because we shift, gap is included as nan values in the series.
@@ -155,15 +187,22 @@ def test_roll_series_with_gap_early_values(window_length, gap, rolling_series_pd
 def test_roll_series_with_gap_nullable_types(rolling_series_pd):
     window_length = 3
     gap = 2
+    min_periods = 1
     # Because we're inserting nans, confirm that nullability of the dtype doesn't have an impact on the results
     nullable_series = rolling_series_pd.astype("Int64")
     non_nullable_series = rolling_series_pd.astype("int64")
 
     nullable_rolling_max = roll_series_with_gap(
-        nullable_series, window_length, gap=gap
+        nullable_series,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
     ).max()
     non_nullable_rolling_max = roll_series_with_gap(
-        non_nullable_series, window_length, gap=gap
+        non_nullable_series,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
     ).max()
 
     pd.testing.assert_series_equal(nullable_rolling_max, non_nullable_rolling_max)
@@ -172,24 +211,32 @@ def test_roll_series_with_gap_nullable_types(rolling_series_pd):
 def test_roll_series_with_gap_nullable_types_with_nans(rolling_series_pd):
     window_length = 3
     gap = 2
+    min_periods = 1
     nullable_floats = rolling_series_pd.astype("float64").replace(
-        {1: np.nan, 3: np.nan}
+        {1: np.nan, 3: np.nan},
     )
     nullable_ints = nullable_floats.astype("Int64")
 
     nullable_ints_rolling_max = roll_series_with_gap(
-        nullable_ints, window_length, gap=gap
+        nullable_ints,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
     ).max()
     nullable_floats_rolling_max = roll_series_with_gap(
-        nullable_floats, window_length, gap=gap
+        nullable_floats,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
     ).max()
 
     pd.testing.assert_series_equal(
-        nullable_ints_rolling_max, nullable_floats_rolling_max
+        nullable_ints_rolling_max,
+        nullable_floats_rolling_max,
     )
 
     expected_early_values = [np.nan, np.nan, 0, 0, 2, 2, 4] + list(
-        range(7 - gap, len(rolling_series_pd) - gap)
+        range(7 - gap, len(rolling_series_pd) - gap),
     )
     for i in range(len(rolling_series_pd)):
         actual = nullable_floats_rolling_max.iloc[i]
@@ -213,13 +260,23 @@ def test_apply_roll_with_offset_gap(window_length, gap, rolling_series_pd):
     def max_wrapper(sub_s):
         return apply_roll_with_offset_gap(sub_s, gap, max, min_periods=1)
 
-    rolling_max_obj = roll_series_with_gap(rolling_series_pd, window_length, gap=gap)
+    rolling_max_obj = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=1,
+    )
     rolling_max_series = rolling_max_obj.apply(max_wrapper)
 
     def min_wrapper(sub_s):
         return apply_roll_with_offset_gap(sub_s, gap, min, min_periods=1)
 
-    rolling_min_obj = roll_series_with_gap(rolling_series_pd, window_length, gap=gap)
+    rolling_min_obj = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=1,
+    )
     rolling_min_series = rolling_min_obj.apply(min_wrapper)
 
     assert len(rolling_max_series) == len(rolling_series_pd)
@@ -260,7 +317,12 @@ def test_apply_roll_with_offset_gap_default_min_periods(min_periods, rolling_ser
     def count_wrapper(sub_s):
         return apply_roll_with_offset_gap(sub_s, gap, len, min_periods=min_periods)
 
-    rolling_count_obj = roll_series_with_gap(rolling_series_pd, window_length, gap=gap)
+    rolling_count_obj = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
+    )
     rolling_count_series = rolling_count_obj.apply(count_wrapper)
 
     # gap essentially creates a rolling series that has no elements; which should be nan
@@ -269,7 +331,7 @@ def test_apply_roll_with_offset_gap_default_min_periods(min_periods, rolling_ser
     num_partial_aggregates = len(
         (rolling_count_series.loc[rolling_count_series != 0]).loc[
             rolling_count_series < window_length_num
-        ]
+        ],
     )
 
     assert num_empty_aggregates == gap_num
@@ -289,7 +351,12 @@ def test_apply_roll_with_offset_gap_min_periods(min_periods, rolling_series_pd):
     def count_wrapper(sub_s):
         return apply_roll_with_offset_gap(sub_s, gap, len, min_periods=min_periods)
 
-    rolling_count_obj = roll_series_with_gap(rolling_series_pd, window_length, gap=gap)
+    rolling_count_obj = roll_series_with_gap(
+        rolling_series_pd,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
+    )
     rolling_count_series = rolling_count_obj.apply(count_wrapper)
 
     # gap essentially creates rolling series that have no elements; which should be nan
@@ -298,7 +365,7 @@ def test_apply_roll_with_offset_gap_min_periods(min_periods, rolling_series_pd):
     num_partial_aggregates = len(
         (rolling_count_series.loc[rolling_count_series != 0]).loc[
             rolling_count_series < window_length_num
-        ]
+        ],
     )
 
     assert num_empty_aggregates == min_periods - 1 + gap_num
@@ -308,6 +375,7 @@ def test_apply_roll_with_offset_gap_min_periods(min_periods, rolling_series_pd):
 def test_apply_roll_with_offset_gap_non_uniform():
     window_length = "3d"
     gap = "3d"
+    min_periods = 1
     # When the data isn't uniform, this impacts the number of values in each rolling window
     datetimes = (
         list(pd.date_range(start="2017-01-01", freq="1d", periods=7))
@@ -326,9 +394,14 @@ def test_apply_roll_with_offset_gap_non_uniform():
     )
 
     def count_wrapper(sub_s):
-        return apply_roll_with_offset_gap(sub_s, gap, len, min_periods=1)
+        return apply_roll_with_offset_gap(sub_s, gap, len, min_periods=min_periods)
 
-    rolling_count_obj = roll_series_with_gap(no_freq_series, window_length, gap=gap)
+    rolling_count_obj = roll_series_with_gap(
+        no_freq_series,
+        window_length,
+        gap=gap,
+        min_periods=min_periods,
+    )
     rolling_count_series = rolling_count_obj.apply(count_wrapper)
 
     pd.testing.assert_series_equal(rolling_count_series, expected_series)
@@ -351,7 +424,10 @@ def test_apply_roll_with_offset_data_frequency_higher_than_parameters_frequency(
         return apply_roll_with_offset_gap(sub_s, gap, max, min_periods=min_periods)
 
     rolling_max_obj = roll_series_with_gap(
-        high_frequency_series, window_length, min_periods=min_periods, gap=gap
+        high_frequency_series,
+        window_length,
+        min_periods=min_periods,
+        gap=gap,
     )
     rolling_max_series = rolling_max_obj.apply(max_wrapper)
 
@@ -365,7 +441,10 @@ def test_apply_roll_with_offset_data_frequency_higher_than_parameters_frequency(
         return apply_roll_with_offset_gap(sub_s, gap, max, min_periods=min_periods)
 
     rolling_max_obj = roll_series_with_gap(
-        high_frequency_series, window_length, min_periods=min_periods, gap=gap
+        high_frequency_series,
+        window_length,
+        min_periods=min_periods,
+        gap=gap,
     )
     rolling_max_series = rolling_max_obj.apply(max_wrapper)
 
@@ -379,7 +458,10 @@ def test_apply_roll_with_offset_data_frequency_higher_than_parameters_frequency(
         return apply_roll_with_offset_gap(sub_s, gap, max, min_periods=min_periods)
 
     rolling_max_obj = roll_series_with_gap(
-        high_frequency_series, window_length, min_periods=min_periods, gap=gap
+        high_frequency_series,
+        window_length,
+        min_periods=min_periods,
+        gap=gap,
     )
     rolling_max_series = rolling_max_obj.apply(max_wrapper)
 
@@ -397,7 +479,10 @@ def test_apply_roll_with_offset_data_min_periods_too_big(rolling_series_pd):
         return apply_roll_with_offset_gap(sub_s, gap, max, min_periods=min_periods)
 
     rolling_max_obj = roll_series_with_gap(
-        rolling_series_pd, window_length, min_periods=min_periods, gap=gap
+        rolling_series_pd,
+        window_length,
+        min_periods=min_periods,
+        gap=gap,
     )
     rolling_max_series = rolling_max_obj.apply(max_wrapper)
 
@@ -414,17 +499,29 @@ def test_roll_series_with_gap_different_input_types_same_result_uniform(
     offset_window_length = "5d"
     int_gap = 2
     int_window_length = 5
+    min_periods = 1
 
     # Rolling series' with matching input types
     expected_rolling_numeric = roll_series_with_gap(
-        rolling_series_pd, window_size=int_window_length, gap=int_gap
+        rolling_series_pd,
+        window_length=int_window_length,
+        gap=int_gap,
+        min_periods=min_periods,
     ).max()
 
     def count_wrapper(sub_s):
-        return apply_roll_with_offset_gap(sub_s, offset_gap, max, min_periods=1)
+        return apply_roll_with_offset_gap(
+            sub_s,
+            offset_gap,
+            max,
+            min_periods=min_periods,
+        )
 
     rolling_count_obj = roll_series_with_gap(
-        rolling_series_pd, window_size=offset_window_length, gap=offset_gap
+        rolling_series_pd,
+        window_length=offset_window_length,
+        gap=offset_gap,
+        min_periods=min_periods,
     )
     expected_rolling_offset = rolling_count_obj.apply(count_wrapper)
 
@@ -433,7 +530,10 @@ def test_roll_series_with_gap_different_input_types_same_result_uniform(
 
     # Rolling series' with mismatched input types
     mismatched_numeric_gap = roll_series_with_gap(
-        rolling_series_pd, window_size=offset_window_length, gap=int_gap
+        rolling_series_pd,
+        window_length=offset_window_length,
+        gap=int_gap,
+        min_periods=min_periods,
     ).max()
     # Confirm the mismatched results also produce the same results
     pd.testing.assert_series_equal(expected_rolling_numeric, mismatched_numeric_gap)
@@ -442,31 +542,46 @@ def test_roll_series_with_gap_different_input_types_same_result_uniform(
 def test_roll_series_with_gap_incorrect_types(rolling_series_pd):
     error = "Window length must be either an offset string or an integer."
     with pytest.raises(TypeError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size=4.2, gap=4)
+        roll_series_with_gap(
+            rolling_series_pd,
+            window_length=4.2,
+            gap=4,
+            min_periods=1,
+        ),
 
     error = "Gap must be either an offset string or an integer."
     with pytest.raises(TypeError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size=4, gap=4.2)
+        roll_series_with_gap(rolling_series_pd, window_length=4, gap=4.2, min_periods=1)
 
 
 def test_roll_series_with_gap_negative_inputs(rolling_series_pd):
     error = "Window length must be greater than zero."
     with pytest.raises(ValueError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size=-4, gap=4)
+        roll_series_with_gap(rolling_series_pd, window_length=-4, gap=4, min_periods=1)
 
     error = "Gap must be greater than or equal to zero."
     with pytest.raises(ValueError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size=4, gap=-4)
+        roll_series_with_gap(rolling_series_pd, window_length=4, gap=-4, min_periods=1)
 
 
 def test_roll_series_with_non_offset_string_inputs(rolling_series_pd):
     error = "Cannot roll series. The specified gap, test, is not a valid offset alias."
     with pytest.raises(ValueError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size="4D", gap="test")
+        roll_series_with_gap(
+            rolling_series_pd,
+            window_length="4D",
+            gap="test",
+            min_periods=1,
+        )
 
     error = "Cannot roll series. The specified window length, test, is not a valid offset alias."
     with pytest.raises(ValueError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size="test", gap="7D")
+        roll_series_with_gap(
+            rolling_series_pd,
+            window_length="test",
+            gap="7D",
+            min_periods=1,
+        )
 
     # Test mismatched types error
     error = (
@@ -475,4 +590,78 @@ def test_roll_series_with_non_offset_string_inputs(rolling_series_pd):
         "Please either change gap to be numeric or change window length to be an offset alias."
     )
     with pytest.raises(TypeError, match=error):
-        roll_series_with_gap(rolling_series_pd, window_size=7, gap="2d").max()
+        roll_series_with_gap(
+            rolling_series_pd,
+            window_length=7,
+            gap="2d",
+            min_periods=1,
+        ).max()
+
+
+@pytest.mark.parametrize(
+    "primitive",
+    [RollingCount, RollingMax, RollingMin, RollingMean, RollingSTD, RollingTrend],
+)
+@patch("featuretools.primitives.rolling_primitive_utils.apply_roll_with_offset_gap")
+def test_no_call_to_apply_roll_with_offset_gap_with_numeric(
+    mock_apply_roll,
+    primitive,
+    rolling_series_pd,
+):
+    assert not mock_apply_roll.called
+
+    fully_numeric_primitive = primitive(window_length=3, gap=1)
+    primitive_func = fully_numeric_primitive.get_function()
+    if isinstance(fully_numeric_primitive, RollingCount):
+        pd.Series(primitive_func(rolling_series_pd.index))
+    else:
+        pd.Series(
+            primitive_func(
+                rolling_series_pd.index,
+                pd.Series(rolling_series_pd.values),
+            ),
+        )
+
+    assert not mock_apply_roll.called
+
+    offset_window_primitive = primitive(window_length="3d", gap=1)
+    primitive_func = offset_window_primitive.get_function()
+    if isinstance(offset_window_primitive, RollingCount):
+        pd.Series(primitive_func(rolling_series_pd.index))
+    else:
+        pd.Series(
+            primitive_func(
+                rolling_series_pd.index,
+                pd.Series(rolling_series_pd.values),
+            ),
+        )
+
+    assert not mock_apply_roll.called
+
+    no_gap_specified_primitive = primitive(window_length="3d")
+    primitive_func = no_gap_specified_primitive.get_function()
+    if isinstance(no_gap_specified_primitive, RollingCount):
+        pd.Series(primitive_func(rolling_series_pd.index))
+    else:
+        pd.Series(
+            primitive_func(
+                rolling_series_pd.index,
+                pd.Series(rolling_series_pd.values),
+            ),
+        )
+
+    assert not mock_apply_roll.called
+
+    no_gap_specified_primitive = primitive(window_length="3d", gap="1d")
+    primitive_func = no_gap_specified_primitive.get_function()
+    if isinstance(no_gap_specified_primitive, RollingCount):
+        pd.Series(primitive_func(rolling_series_pd.index))
+    else:
+        pd.Series(
+            primitive_func(
+                rolling_series_pd.index,
+                pd.Series(rolling_series_pd.values),
+            ),
+        )
+
+    assert mock_apply_roll.called
